      SUBROUTINE CHECK(U,NAPTS,UMIN,UMAX)
*
*
*  This software was developed by the Thermal Modeling and Analysis
*  Project(TMAP) of the National Oceanographic and Atmospheric
*  Administration's (NOAA) Pacific Marine Environmental Lab(PMEL),
*  hereafter referred to as NOAA/PMEL/TMAP.
*
*  Access and use of this software shall impose the following
*  obligations and understandings on the user. The user is granted the
*  right, without any fee or cost, to use, copy, modify, alter, enhance
*  and distribute this software, and any derivative works thereof, and
*  its supporting documentation for any purpose whatsoever, provided
*  that this entire notice appears in all copies of the software,
*  derivative works and supporting documentation.  Further, the user
*  agrees to credit NOAA/PMEL/TMAP in any publications that result from
*  the use of this software or in any product that includes this
*  software. The names TMAP, NOAA and/or PMEL, however, may not be used
*  in any advertising or publicity to endorse or promote any products
*  or commercial entity unless specific written permission is obtained
*  from NOAA/PMEL/TMAP. The user also understands that NOAA/PMEL/TMAP
*  is not obligated to provide the user with any support, consulting,
*  training or assistance of any kind with regard to the use, operation
*  and performance of this software nor to provide the user with any
*  updates, revisions, new versions or "bug fixes".
*
*  THIS SOFTWARE IS PROVIDED BY NOAA/PMEL/TMAP "AS IS" AND ANY EXPRESS
*  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
*  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
*  ARE DISCLAIMED. IN NO EVENT SHALL NOAA/PMEL/TMAP BE LIABLE FOR ANY SPECIAL,
*  INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
*  RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
*  CONTRACT, NEGLIGENCE OR OTHER TORTUOUS ACTION, ARISING OUT OF OR IN
*  CONNECTION WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE. 
*
*
C**    @(#)check.f	1.1    3/10/88
C**
C**
C***********************************************************************
C**
C**                 PLOT+ Scientific Graphics System
C**
C***********************************************************************
C**
C**
C
C     CALL CHECK(U,NPTS,UMIN,UMAX)
C
C     THIS SUBROUTINE CHECKS AN ARRAY OF FLOATING-POINT NUMBERS
C     AND RETURNS THE ALGEBRAIC MINIMUM AND MAXIMUM.
C
C     THE VARIOUS PARAMETERS AND THEIR DEFINITIONS ARE LISTED
C     BELOW:
C        U      - ARRAY CONTAINING THE FLOATING-POINT NUMBERS
C                 TO BE CHECKED.
C        NPTS   - NUMBER OF ENTRIES IN THE ARRAY.
C        UMIN   - MINIMUM VALUE IN THE ARRAY.
C        UMAX   - MAXIMUM VALUE IN THE ARRAY.
C
C
      DIMENSION U(1)
C
      IF(NAPTS .EQ. 0)RETURN
      NPTS = IABS(NAPTS)
C
C     INITIALIZE THE MINIMUM AND MAXIMUM TO THE FIRST ENTRY.
C
      UMIN = U(1)
      UMAX = U(1)
      IF(NPTS .EQ. 1)RETURN
C
C     CHECK THE REST OF THE ENTRIES FOR ALGEBRAICALLY SMALLER
C     AND LARGER VALUES.
C
      DO 10 I=2,NPTS
      IF(U(I) .LT. UMIN)UMIN = U(I)
   10 IF(U(I) .GT. UMAX)UMAX = U(I)
      RETURN
C
      END
